@@ -15,7 +15,7 @@
   GNU General Public License for more details.
 
   You should have received a copy of the GNU General Public License
-  along with this program. If not, see http://www.gnu.org/licenses/.
+  along with this program. If not, see https://www.gnu.org/licenses/.
 */
 
 #include "mainwindow.h"
@@ -43,7 +43,7 @@ int main (int argc, char *argv[])
         KAboutLicense::GPL,
         xi18nc("@info:credit", "(c) 2008-2018 The Yakuake Team"),
         QString(),
-        QStringLiteral("http://yakuake.kde.org/"));
+        QStringLiteral("https://kde.org/applications/system/org.kde.yakuake"));
 
     aboutData.setOrganizationDomain(QByteArray("kde.org"));
     aboutData.setProductName(QByteArray("yakuake"));
@@ -66,8 +66,6 @@ int main (int argc, char *argv[])
 
     KAboutData::setApplicationData(aboutData);
     QCommandLineParser parser;
-    parser.addHelpOption();
-    parser.addVersionOption();
 
     aboutData.setupCommandLine(&parser);
     parser.process(app);
